Structs
- Components
- Discriminator
- Info
- Media
Type - Open
ApiSpec - Top-level OpenAPI 3.0/3.1 specification.
- Operation
- Parameter
- Path
Item - Request
Body - Response
- Schema
Enums
- Additional
Properties additionalPropertiescan be a boolean or a schema.true→ Record<string, unknown>,false→ no extra props, schema → Record<string, T>- Parameter
OrRef - A parameter that can be inline or a $ref to components/parameters.
- Request
Body OrRef - A request body that can be inline or a $ref to components/requestBodies.
- Response
OrRef - A response that can be inline or a $ref to components/responses.
- Schema
OrRef - A schema that can be either inline or a $ref.
- Schema
Type - OpenAPI 3.1 allows
typeto be either a string or an array of strings. e.g.type: "string"(3.0) ortype: ["string", "null"](3.1)