pub fn detect_circular_refs(
schema: &SchemaOrRef,
components: Option<&Components>,
visited: &mut HashSet<String>,
) -> boolExpand description
Detect circular references in a schema graph using DFS.
pub fn detect_circular_refs(
schema: &SchemaOrRef,
components: Option<&Components>,
visited: &mut HashSet<String>,
) -> boolDetect circular references in a schema graph using DFS.