Module openapi

Module openapi 

Structs

Components
Discriminator
Info
MediaType
OpenApiSpec
Top-level OpenAPI 3.0/3.1 specification.
Operation
Parameter
PathItem
RequestBody
Response
Schema

Enums

ParameterOrRef
A parameter that can be inline or a $ref to components/parameters.
RequestBodyOrRef
A request body that can be inline or a $ref to components/requestBodies.
ResponseOrRef
A response that can be inline or a $ref to components/responses.
SchemaOrRef
A schema that can be either inline or a $ref.
SchemaType
OpenAPI 3.1 allows type to be either a string or an array of strings. e.g. type: "string" (3.0) or type: ["string", "null"] (3.1)